import { GetParametersByPathCommand, SSMClient } from '@aws-sdk/client-ssm';
import { Injectable, Inject, Logger, Global, Module } from '@nestjs/common';

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise, SuppressedError, Symbol, Iterator */


function __decorate(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}

function __param(paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
}

function __metadata(metadataKey, metadataValue) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(metadataKey, metadataValue);
}

typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
    var e = new Error(message);
    return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
};

const PARAMETER_STORE_CONFIG_PROPERTIES = "PARAMETER_STORE_CONFIG_PROPERTIES";
const PARAMETER_STORE_CONFIG_PARAMETERS = "PARAMETER_STORE_CONFIG_PARAMETERS";
const PARAMETER_STORE_SSM_CLIENT = "PARAMETER_STORE_SSM_CLIENT";

let ParameterStoreService = class ParameterStoreService {
    client;
    constructor(client) {
        this.client = client;
    }
    async getParametersByPath(path, decryptParameters = false, recursiveLoading = false, verbose = false) {
        if (verbose)
            Logger.verbose(`Getting parameters from path: ${path}`, "ParameterStoreConfig");
        let allParameters = [];
        let nextParametersToken;
        do {
            const getParameters = new GetParametersByPathCommand({
                NextToken: nextParametersToken,
                Path: path,
                Recursive: recursiveLoading,
                WithDecryption: decryptParameters,
            });
            const { NextToken, Parameters = [] } = await this.client.send(getParameters);
            allParameters = [...allParameters, ...Parameters];
            nextParametersToken = NextToken;
        } while (nextParametersToken);
        if (verbose)
            Logger.verbose(`Found ${String(allParameters.length)} parameters`, "ParameterStoreConfig");
        return allParameters;
    }
};
ParameterStoreService = __decorate([
    Injectable(),
    __param(0, Inject(PARAMETER_STORE_SSM_CLIENT)),
    __metadata("design:paramtypes", [SSMClient])
], ParameterStoreService);

const ParameterStoreConfigParametersProvider = {
    inject: [PARAMETER_STORE_CONFIG_PROPERTIES, ParameterStoreService],
    provide: PARAMETER_STORE_CONFIG_PARAMETERS,
    useFactory: async (properties, parameterStoreService) => {
        let path;
        if (properties.basePath) {
            path = properties.basePath;
        }
        else if (properties.application) {
            path = `/${properties.application}`;
            if (properties.environment) {
                path = `${path}/${properties.environment}`;
            }
        }
        else {
            path = "/";
        }
        return parameterStoreService.getParametersByPath(path, properties.shouldDecryptParameters ?? false, properties.shouldUseRecursiveLoading ?? false, properties.isVerbose ?? false);
    },
};

const ParameterStoreConfigPropertiesProvider = (options) => {
    return {
        provide: PARAMETER_STORE_CONFIG_PROPERTIES,
        useValue: options,
    };
};

const ParameterStoreConfigSSMProvider = {
    inject: [PARAMETER_STORE_CONFIG_PROPERTIES],
    provide: PARAMETER_STORE_SSM_CLIENT,
    useFactory: (properties) => {
        return new SSMClient(properties.config ?? {});
    },
};

var EEnvironment;
(function (EEnvironment) {
    EEnvironment["DOCKER"] = "docker";
    EEnvironment["EC2"] = "ec2";
    EEnvironment["ECS"] = "ecs";
    EEnvironment["EKS"] = "eks";
    EEnvironment["ELASTIC_BEANSTALK"] = "elastic-beanstalk";
    EEnvironment["HEROKU"] = "heroku";
    EEnvironment["KUBERNETES"] = "kubernetes";
    EEnvironment["LOCAL"] = "local";
    EEnvironment["PRODUCTION"] = "production";
    EEnvironment["STAGING"] = "staging";
    EEnvironment["TEST"] = "test";
})(EEnvironment || (EEnvironment = {}));

var EInstanceName;
(function (EInstanceName) {
    EInstanceName["REAPER_API"] = "reaper-api";
    EInstanceName["REAPER_API_TEST"] = "reaper-api-test";
})(EInstanceName || (EInstanceName = {}));

var EService;
(function (EService) {
    EService["AB_TESTING"] = "ab-testing";
    EService["ACTIVEMQ"] = "activemq";
    EService["ADDRESS_VALIDATION"] = "address-validation";
    EService["ADMIN_API"] = "admin-api";
    EService["ADYEN"] = "adyen";
    EService["ALERT_MANAGER"] = "alert-manager";
    EService["ALGOLIA"] = "algolia";
    EService["AMPLITUDE"] = "amplitude";
    EService["ANALYTICS_SERVICE"] = "analytics-service";
    EService["ANTHROPIC"] = "anthropic";
    EService["APACHE"] = "apache";
    EService["API_GATEWAY"] = "api-gateway";
    EService["APPLE_AUTH"] = "apple-auth";
    EService["AUDIO_PROCESSING"] = "audio-processing";
    EService["AUTH_SERVICE"] = "auth-service";
    EService["AUTH0"] = "auth0";
    EService["AWS_API_GATEWAY"] = "aws-api-gateway";
    EService["AWS_APP_SYNC"] = "aws-app-sync";
    EService["AWS_ATHENA"] = "aws-athena";
    EService["AWS_BATCH"] = "aws-batch";
    EService["AWS_CLOUDFRONT"] = "aws-cloudfront";
    EService["AWS_CLOUDWATCH"] = "aws-cloudwatch";
    EService["AWS_COGNITO"] = "aws-cognito";
    EService["AWS_DOCUMENTDB"] = "aws-documentdb";
    EService["AWS_DYNAMODB"] = "aws-dynamodb";
    EService["AWS_EC2"] = "aws-ec2";
    EService["AWS_ECS"] = "aws-ecs";
    EService["AWS_ELASTIC_BEANSTALK"] = "aws-elastic-beanstalk";
    EService["AWS_ELASTICACHE"] = "aws-elasticache";
    EService["AWS_ELASTICSEARCH"] = "aws-elasticsearch";
    EService["AWS_EVENTBRIDGE"] = "aws-eventbridge";
    EService["AWS_FARGATE"] = "aws-fargate";
    EService["AWS_GLUE"] = "aws-glue";
    EService["AWS_IOT"] = "aws-iot";
    EService["AWS_KINESIS"] = "aws-kinesis";
    EService["AWS_LAMBDA"] = "aws-lambda";
    EService["AWS_NEPTUNE"] = "aws-neptune";
    EService["AWS_OPENSEARCH"] = "aws-opensearch";
    EService["AWS_RDS"] = "aws-rds";
    EService["AWS_REDSHIFT"] = "aws-redshift";
    EService["AWS_ROUTE53"] = "aws-route53";
    EService["AWS_S3"] = "aws-s3";
    EService["AWS_SECRETS_MANAGER"] = "aws-secrets-manager";
    EService["AWS_SNS"] = "aws-sns";
    EService["AWS_SQS"] = "aws-sqs";
    EService["AWS_STEP_FUNCTIONS"] = "aws-step-functions";
    EService["AWS_TIMESTREAM"] = "aws-timestream";
    EService["AZURE_ACTIVE_DIRECTORY"] = "azure-active-directory";
    EService["AZURE_APP_SERVICE"] = "azure-app-service";
    EService["AZURE_BLOB_STORAGE"] = "azure-blob-storage";
    EService["AZURE_COSMOS_DB"] = "azure-cosmos-db";
    EService["AZURE_FUNCTIONS"] = "azure-functions";
    EService["AZURE_KEY_VAULT"] = "azure-key-vault";
    EService["AZURE_SERVICE_BUS"] = "azure-service-bus";
    EService["AZURE_SQL"] = "azure-sql";
    EService["BACKBLAZE"] = "backblaze";
    EService["BRAINTREE"] = "braintree";
    EService["CACHE"] = "cache";
    EService["CART_SERVICE"] = "cart-service";
    EService["CASSANDRA"] = "cassandra";
    EService["CDN"] = "cdn";
    EService["CERTIFICATE_MANAGER"] = "certificate-manager";
    EService["CHARGEBEE"] = "chargebee";
    EService["CIRCLECI"] = "circleci";
    EService["CLARIFAI"] = "clarifai";
    EService["CLEARBIT"] = "clearbit";
    EService["CLICKHOUSE"] = "clickhouse";
    EService["CLOUDFLARE"] = "cloudflare";
    EService["CLOUDINARY"] = "cloudinary";
    EService["CMS"] = "cms";
    EService["COCKROACHDB"] = "cockroachdb";
    EService["COHERE"] = "cohere";
    EService["CONSUL"] = "consul";
    EService["CONTENT_SERVICE"] = "content-service";
    EService["COUCHBASE"] = "couchbase";
    EService["CYPRESS"] = "cypress";
    EService["DATADOG"] = "datadog";
    EService["DATADOG_CI"] = "datadog-ci";
    EService["DDOS_PROTECTION"] = "ddos-protection";
    EService["DGRAPH"] = "dgraph";
    EService["DIGITALOCEAN_SPACES"] = "digitalocean-spaces";
    EService["DISCORD_AUTH"] = "discord-auth";
    EService["DOCKER"] = "docker";
    EService["ELASTICSEARCH"] = "elasticsearch";
    EService["EMAIL_SERVICE"] = "email-service";
    EService["ENVOY"] = "envoy";
    EService["ESLINT"] = "eslint";
    EService["EXPERIMENT_SERVICE"] = "experiment-service";
    EService["FACEBOOK_AUTH"] = "facebook-auth";
    EService["FASTLY"] = "fastly";
    EService["FEATURE_FLAGS"] = "feature-flags";
    EService["FILE_SERVICE"] = "file-service";
    EService["FILEBASE"] = "filebase";
    EService["GCP_APP_ENGINE"] = "gcp-app-engine";
    EService["GCP_BIGQUERY"] = "gcp-bigquery";
    EService["GCP_BIGTABLE"] = "gcp-bigtable";
    EService["GCP_CLOUD_FUNCTIONS"] = "gcp-cloud-functions";
    EService["GCP_CLOUD_RUN"] = "gcp-cloud-run";
    EService["GCP_CLOUD_SQL"] = "gcp-cloud-sql";
    EService["GCP_CLOUD_STORAGE"] = "gcp-cloud-storage";
    EService["GCP_COMPUTE_ENGINE"] = "gcp-compute-engine";
    EService["GCP_DATASTORE"] = "gcp-datastore";
    EService["GCP_FIRESTORE"] = "gcp-firestore";
    EService["GCP_PUBSUB"] = "gcp-pubsub";
    EService["GCP_SPANNER"] = "gcp-spanner";
    EService["GITHUB"] = "github";
    EService["GITHUB_ACTIONS"] = "github-actions";
    EService["GITHUB_AUTH"] = "github-auth";
    EService["GITLAB"] = "gitlab";
    EService["GOOGLE_AUTH"] = "google-auth";
    EService["GRAFANA"] = "grafana";
    EService["HAPROXY"] = "haproxy";
    EService["HEALTH_CHECK"] = "health-check";
    EService["HUBSPOT"] = "hubspot";
    EService["HUGGINGFACE"] = "huggingface";
    EService["IDENTITY_PROVIDER"] = "identity-provider";
    EService["IMAGE_PROCESSING"] = "image-processing";
    EService["IMGIX"] = "imgix";
    EService["INFLUXDB"] = "influxdb";
    EService["INTERCOM"] = "intercom";
    EService["INVENTORY_SERVICE"] = "inventory-service";
    EService["IOT_ANALYTICS"] = "iot-analytics";
    EService["IOT_CORE"] = "iot-core";
    EService["IOT_EVENTS"] = "iot-events";
    EService["ISTIO"] = "istio";
    EService["JENKINS"] = "jenkins";
    EService["JEST"] = "jest";
    EService["KAFKA"] = "kafka";
    EService["KUBERNETES"] = "kubernetes";
    EService["LANGCHAIN"] = "langchain";
    EService["LINKEDIN_AUTH"] = "linkedin-auth";
    EService["LINKERD"] = "linkerd";
    EService["LINODE_OBJECT_STORAGE"] = "linode-object-storage";
    EService["LOAD_BALANCER"] = "load-balancer";
    EService["LOCATION_SERVICE"] = "location-service";
    EService["LOG_MANAGER"] = "log-manager";
    EService["MAILCHIMP"] = "mailchimp";
    EService["MAILGUN"] = "mailgun";
    EService["MARIADB"] = "mariadb";
    EService["MESSAGING_SERVICE"] = "messaging-service";
    EService["METRICS_SERVICE"] = "metrics-service";
    EService["MICROSOFT_AUTH"] = "microsoft-auth";
    EService["MILVUS"] = "milvus";
    EService["MINIO"] = "minio";
    EService["MIXPANEL"] = "mixpanel";
    EService["MONGODB"] = "mongodb";
    EService["MQTT"] = "mqtt";
    EService["MYSQL"] = "mysql";
    EService["NATS"] = "nats";
    EService["NEO4J"] = "neo4j";
    EService["NEWRELIC"] = "newrelic";
    EService["NGINX"] = "nginx";
    EService["NOTIFICATION_SERVICE"] = "notification-service";
    EService["OKTA"] = "okta";
    EService["OPENAI"] = "openai";
    EService["ORACLE"] = "oracle";
    EService["ORDER_SERVICE"] = "order-service";
    EService["PAYMENT_SERVICE"] = "payment-service";
    EService["PAYPAL"] = "paypal";
    EService["PINECONE"] = "pinecone";
    EService["PLAID"] = "plaid";
    EService["POSTGRES"] = "postgres";
    EService["POSTMARK"] = "postmark";
    EService["PRODUCT_SERVICE"] = "product-service";
    EService["PROMETHEUS"] = "prometheus";
    EService["PUBNUB"] = "pubnub";
    EService["PULSAR"] = "pulsar";
    EService["PUSHER"] = "pusher";
    EService["PYTORCH_SERVE"] = "pytorch-serve";
    EService["QDRANT"] = "qdrant";
    EService["RABBITMQ"] = "rabbitmq";
    EService["REAPER_API"] = "reaper-api";
    EService["RECOMMENDATION_SERVICE"] = "recommendation-service";
    EService["RECURLY"] = "recurly";
    EService["REDIS"] = "redis";
    EService["REPLICATE"] = "replicate";
    EService["REPORTING_SERVICE"] = "reporting-service";
    EService["RETHINKDB"] = "rethinkdb";
    EService["SCHEDULER_SERVICE"] = "scheduler-service";
    EService["SCYLLADB"] = "scylladb";
    EService["SEARCH_SERVICE"] = "search-service";
    EService["SEGMENT"] = "segment";
    EService["SENDGRID"] = "sendgrid";
    EService["SENTRY"] = "sentry";
    EService["SENTRY_DEBUG"] = "sentry-debug";
    EService["SHIPPING_SERVICE"] = "shipping-service";
    EService["SHOPIFY"] = "shopify";
    EService["SLACK"] = "slack";
    EService["SMS_SERVICE"] = "sms-service";
    EService["SONARQUBE"] = "sonarqube";
    EService["SQL_SERVER"] = "sql-server";
    EService["SQLITE"] = "sqlite";
    EService["STRIPE"] = "stripe";
    EService["TAX_SERVICE"] = "tax-service";
    EService["TEAMCITY"] = "teamcity";
    EService["TENSORFLOW_SERVING"] = "tensorflow-serving";
    EService["TERRAFORM"] = "terraform";
    EService["TIMESCALEDB"] = "timescaledb";
    EService["TRACING_SERVICE"] = "tracing-service";
    EService["TRAEFIK"] = "traefik";
    EService["TRAVIS_CI"] = "travis-ci";
    EService["TWILIO"] = "twilio";
    EService["TWITCH_AUTH"] = "twitch-auth";
    EService["TWITTER_AUTH"] = "twitter-auth";
    EService["UPLOADCARE"] = "uploadcare";
    EService["USER_SERVICE"] = "user-service";
    EService["VAULT"] = "vault";
    EService["VERTEX_AI"] = "vertex-ai";
    EService["VIDEO_PROCESSING"] = "video-processing";
    EService["WAF"] = "waf";
    EService["WASABI"] = "wasabi";
    EService["WEAVIATE"] = "weaviate";
    EService["WORKFLOW_ENGINE"] = "workflow-engine";
    EService["ZENDESK"] = "zendesk";
    EService["ZEROMQ"] = "zeromq";
})(EService || (EService = {}));

let ParameterStoreConfigService = class ParameterStoreConfigService {
    parameters;
    constructor(parameters) {
        this.parameters = parameters;
    }
    get(properties) {
        if (typeof properties === "string") {
            const found = this.parameters.find((parameter) => parameter.Name == properties);
            if (!found?.Value) {
                return null;
            }
            return found.Value;
        }
        else {
            const { application = this.getApplication(), environment = this.getEnvironment(), path = [], service = "" } = properties;
            let instanceName = properties.instanceName ?? `${application}-${EInstanceName.REAPER_API}`;
            if (properties.instanceName === EInstanceName.REAPER_API || properties.instanceName === EInstanceName.REAPER_API_TEST) {
                instanceName = `${application}-${properties.instanceName}`;
            }
            const parameterPath = `/${application}/${environment}/${instanceName}/${service}/${path.join("/")}`;
            const found = this.parameters.find((parameter) => parameter.Name == parameterPath);
            if (!found?.Value) {
                return null;
            }
            return found.Value;
        }
    }
    getApplication() {
        return process.env.APPLICATION ?? "";
    }
    getEnvironment() {
        return process.env.ENVIRONMENT ?? "";
    }
};
ParameterStoreConfigService = __decorate([
    Injectable(),
    __param(0, Inject(PARAMETER_STORE_CONFIG_PARAMETERS)),
    __metadata("design:paramtypes", [Array])
], ParameterStoreConfigService);

var ParameterStoreConfigModule_1;
let ParameterStoreConfigModule = ParameterStoreConfigModule_1 = class ParameterStoreConfigModule {
    static register(options) {
        const propertiesProvider = ParameterStoreConfigPropertiesProvider(options);
        return {
            exports: [ParameterStoreConfigService, PARAMETER_STORE_CONFIG_PARAMETERS],
            module: ParameterStoreConfigModule_1,
            providers: [propertiesProvider, ParameterStoreConfigParametersProvider, ParameterStoreConfigSSMProvider, ParameterStoreConfigService, ParameterStoreService],
        };
    }
    static registerAsync(properties) {
        const providers = this.createAsyncProviders(properties);
        return {
            exports: [ParameterStoreConfigService, PARAMETER_STORE_CONFIG_PARAMETERS],
            imports: properties.imports ?? [],
            module: ParameterStoreConfigModule_1,
            providers,
        };
    }
    static createAsyncOptionsProvider(properties) {
        if (properties.useFactory) {
            return {
                inject: properties.inject ?? [],
                provide: PARAMETER_STORE_CONFIG_PROPERTIES,
                useFactory: properties.useFactory,
            };
        }
        const inject = properties.useExisting ?? properties.useClass;
        return {
            inject: inject ? [inject] : [],
            provide: PARAMETER_STORE_CONFIG_PROPERTIES,
            useFactory: async (optionsFactory) => {
                return optionsFactory.createOptions();
            },
        };
    }
    static createAsyncProviders(properties) {
        const optionsProvider = this.createAsyncOptionsProvider(properties);
        const requestProviders = [optionsProvider, ParameterStoreConfigParametersProvider, ParameterStoreConfigSSMProvider, ParameterStoreConfigService, ParameterStoreService];
        if (properties.useExisting || properties.useFactory || !properties.useClass) {
            return requestProviders;
        }
        return [
            ...requestProviders,
            {
                provide: properties.useClass,
                useClass: properties.useClass,
            },
        ];
    }
};
ParameterStoreConfigModule = ParameterStoreConfigModule_1 = __decorate([
    Global(),
    Module({})
], ParameterStoreConfigModule);

export { EEnvironment, EInstanceName, EService, PARAMETER_STORE_CONFIG_PARAMETERS, PARAMETER_STORE_CONFIG_PROPERTIES, PARAMETER_STORE_SSM_CLIENT, ParameterStoreConfigModule, ParameterStoreConfigParametersProvider, ParameterStoreConfigPropertiesProvider, ParameterStoreConfigSSMProvider, ParameterStoreConfigService, ParameterStoreService };
//# sourceMappingURL=index.js.map
